@@ -1,6 +1,7 @@
 import os, sys, re, time, threading
 from http.server import ThreadingHTTPServer, BaseHTTPRequestHandler
 from html import escape
+from . import __version__
 
 if sys.platform.startswith("linux"):
     import vdf
@@ -56,14 +57,18 @@ def main():
     #print("\n------\nPython's Turn!\n------\n")
     outfile = sys.argv[1]
     root_path = getAppData()+"/Stormworks/data/vehicles/"
-    data = open(root_path+outfile, newline = "\n").read()
+    data = open(root_path+outfile, newline = '\n').read()
+
+    print(f"pyStormworksLuaInject v{__version__}")
 
     for file in os.scandir(sys.argv[2]):
-        code = open(file.path, newline = "\n").read()
+        code = open(file.path, newline = '\n').read()
         identifier = file.name[:file.name.rindex('.')]
         print(f"Searching '{outfile}' for Lua blocks with identifier '{identifier}'")
         data, c = re.subn(f"script=['\"]--{identifier}[\r\n|\n|\r](.*?)['\"]>", repl, data, flags = re.MULTILINE + re.DOTALL)
-        open(root_path+outfile, "w", newline="\n").write(data)
+        #replace all \r\n with \n
+        data = data.replace("\r\n", "\n")
+        open(root_path+outfile, "w", newline='\n').write(data)
         print(f"\tReplaced {c} Lua blocks with identifier '{identifier}'.")
     #print("\n------\nBack to you, nameous!\n------\n")
 
